@@ -148,21 +148,21 @@ impl RustApp {
                 path
             })
             .unwrap_or_else(|| html_dir.join("Cargo.toml"));
-        let bin = attrs.get("data-bin").map(|val| val.to_string());
-        let target_name = attrs.get("data-target-name").map(|val| val.to_string());
+        let bin = attrs.get("data-bin").map(|attr| attr.to_string());
+        let target_name = attrs.get("data-target-name").map(|attr| attr.to_string());
         let keep_debug = attrs.contains_key("data-keep-debug");
         let typescript = attrs.contains_key("data-typescript");
         let no_demangle = attrs.contains_key("data-no-demangle");
         let app_type = attrs
             .get("data-type")
-            .map(|s| s.parse())
+            .map(|attr| attr.parse())
             .transpose()?
             .unwrap_or(RustAppType::Main);
         let reference_types = attrs.contains_key("data-reference-types");
         let weak_refs = attrs.contains_key("data-weak-refs");
         let wasm_opt = attrs
             .get("data-wasm-opt")
-            .map(|val| val.parse())
+            .map(|attr| attr.parse())
             .transpose()?
             .unwrap_or_else(|| {
                 if cfg.release {
@@ -174,12 +174,12 @@ impl RustApp {
         let wasm_opt_params = attrs
             .get("data-wasm-opt-params")
             .iter()
-            .flat_map(|val| val.split_whitespace())
+            .flat_map(|attr| attr.split_whitespace())
             .map(|val| val.to_string())
             .collect();
         let wasm_bindgen_target = attrs
             .get("data-bindgen-target")
-            .map(|s| s.parse())
+            .map(|attr| attr.parse())
             .transpose()?
             .unwrap_or(match app_type {
                 RustAppType::Main => WasmBindgenTarget::Web,
@@ -187,7 +187,7 @@ impl RustApp {
             });
         let cross_origin = attrs
             .get("data-cross-origin")
-            .map(|val| CrossOrigin::from_str(val))
+            .map(|attr| CrossOrigin::from_str(attr))
             .transpose()?
             .unwrap_or_default();
         let integrity = IntegrityType::from_attrs(&attrs, &cfg)?;
@@ -214,8 +214,9 @@ impl RustApp {
 
         let cargo_profile = match data_cargo_profile {
             Some(cargo_profile) => {
+                let cargo_profile = &cargo_profile.value;
                 if let Some(config_cargo_profile) = &cfg.cargo_profile {
-                    log::warn!("Cargo profile from configuration ({config_cargo_profile}) will be overridden with HTML file's more specific setting ({cargo_profile})");
+                    log::warn!("Cargo profile from configuration ({config_cargo_profile}) will be overridden with HTML file's more specific setting ({})", cargo_profile);
                 }
                 Some(cargo_profile.clone())
             }
@@ -224,7 +225,9 @@ impl RustApp {
 
         // cargo features
 
-        let data_features = attrs.get("data-cargo-features").map(|val| val.to_string());
+        let data_features = attrs
+            .get("data-cargo-features")
+            .map(|attr| attr.to_string());
         let data_all_features = attrs.contains_key("data-cargo-all-features");
         let data_no_default_features = attrs.contains_key("data-cargo-no-default-features");
 
@@ -254,7 +257,10 @@ impl RustApp {
         // bindings
 
         let import_bindings = !attrs.contains_key("data-wasm-no-import");
-        let import_bindings_name = attrs.get("data-wasm-import-name").cloned();
+        let import_bindings_name = attrs
+            .get("data-wasm-import-name")
+            .map(|attr| &attr.value)
+            .cloned();
 
         // progress function
 
